@@ -242,7 +242,7 @@ namespace Aws
              *
              * @return this option object
              */
-            Mqtt5ClientBuilder &withHostName(Crt::String hostname);
+            Mqtt5ClientBuilder &WithHostName(Crt::String hostname);
 
             /**
              * Set port to connect to
@@ -251,7 +251,7 @@ namespace Aws
              *
              * @return this option object
              */
-            Mqtt5ClientBuilder &withPort(uint16_t port) noexcept;
+            Mqtt5ClientBuilder &WithPort(uint16_t port) noexcept;
 
             /**
              * Sets the certificate authority for the endpoint you're connecting to. This is a path to a file on disk
@@ -280,7 +280,7 @@ namespace Aws
              *
              * @return this option object
              */
-            Mqtt5ClientBuilder &withHttpProxyOptions(
+            Mqtt5ClientBuilder &WithHttpProxyOptions(
                 const Crt::Http::HttpClientConnectionProxyOptions &proxyOptions) noexcept;
 
             /**
@@ -297,7 +297,7 @@ namespace Aws
              *
              * @return this option object
              */
-            Mqtt5ClientBuilder &withConnectOptions(std::shared_ptr<ConnectPacket> packetConnect) noexcept;
+            Mqtt5ClientBuilder &WithConnectOptions(std::shared_ptr<ConnectPacket> packetConnect) noexcept;
 
             /**
              * Sets session behavior. Overrides how the MQTT5 client should behave with respect to MQTT sessions.
@@ -306,7 +306,7 @@ namespace Aws
              *
              * @return this option object
              */
-            Mqtt5ClientBuilder &withSessionBehavior(ClientSessionBehaviorType sessionBehavior) noexcept;
+            Mqtt5ClientBuilder &WithSessionBehavior(ClientSessionBehaviorType sessionBehavior) noexcept;
 
             /**
              * Sets client extended validation and flow control, additional controls for client behavior with
@@ -317,7 +317,7 @@ namespace Aws
              *
              * @return this option object
              */
-            Mqtt5ClientBuilder &withClientExtendedValidationAndFlowControl(
+            Mqtt5ClientBuilder &WithClientExtendedValidationAndFlowControl(
                 ClientExtendedValidationAndFlowControl clientExtendedValidationAndFlowControl) noexcept;
 
             /**
@@ -330,7 +330,7 @@ namespace Aws
              *
              * @return this option object
              */
-            Mqtt5ClientBuilder &withOfflineQueueBehavior(
+            Mqtt5ClientBuilder &WithOfflineQueueBehavior(
                 ClientOperationQueueBehaviorType offlineQueueBehavior) noexcept;
 
             /**
@@ -341,7 +341,7 @@ namespace Aws
              *
              * @return this option object
              */
-            Mqtt5ClientBuilder &withReconnectOptions(ReconnectOptions reconnectOptions) noexcept;
+            Mqtt5ClientBuilder &WithReconnectOptions(ReconnectOptions reconnectOptions) noexcept;
 
             /**
              * Sets minConnectedTimeToResetReconnectDelayMs, amount of time that must elapse with an established
@@ -352,7 +352,7 @@ namespace Aws
              *
              * @return this option object
              */
-            Mqtt5ClientBuilder &withMinConnectedTimeToResetReconnectDelayMs(
+            Mqtt5ClientBuilder &WithMinConnectedTimeToResetReconnectDelayMs(
                 uint64_t minConnectedTimeToResetReconnectDelayMs) noexcept;
 
             /**
@@ -363,7 +363,7 @@ namespace Aws
              *
              * @return this option object
              */
-            Mqtt5ClientBuilder &withPingTimeoutMs(uint32_t pingTimeoutMs) noexcept;
+            Mqtt5ClientBuilder &WithPingTimeoutMs(uint32_t pingTimeoutMs) noexcept;
 
             /**
              * Sets Connack Timeout (ms). Time interval to wait after sending a CONNECT request for a CONNACK
@@ -373,7 +373,7 @@ namespace Aws
              *
              * @return this option object
              */
-            Mqtt5ClientBuilder &withConnackTimeoutMs(uint32_t connackTimeoutMs) noexcept;
+            Mqtt5ClientBuilder &WithConnackTimeoutMs(uint32_t connackTimeoutMs) noexcept;
 
             /**
              * Sets Operation Timeout(Seconds). Time interval to wait for an ack after sending a QoS 1+ PUBLISH,
@@ -383,7 +383,7 @@ namespace Aws
              *
              * @return this option object
              */
-            Mqtt5ClientBuilder &withAckTimeoutSeconds(uint32_t ackTimeoutSeconds) noexcept;
+            Mqtt5ClientBuilder &WithAckTimeoutSeconds(uint32_t ackTimeoutSeconds) noexcept;
 
             /**
              * Overrides the default SDK Name to send as a metric in the MQTT CONNECT packet.
@@ -439,7 +439,7 @@ namespace Aws
              *
              * @return this option object
              */
-            Mqtt5ClientBuilder &withClientConnectionSuccessCallback(OnConnectionSuccessHandler callback) noexcept;
+            Mqtt5ClientBuilder &WithClientConnectionSuccessCallback(OnConnectionSuccessHandler callback) noexcept;
 
             /**
              * Setup callback trigged when client fails to establish an MQTT connection
@@ -448,7 +448,7 @@ namespace Aws
              *
              * @return this option object
              */
-            Mqtt5ClientBuilder &withClientConnectionFailureCallback(OnConnectionFailureHandler callback) noexcept;
+            Mqtt5ClientBuilder &WithClientConnectionFailureCallback(OnConnectionFailureHandler callback) noexcept;
 
             /**
              * Setup callback handler trigged when client's current MQTT connection is closed
@@ -457,7 +457,7 @@ namespace Aws
              *
              * @return this option object
              */
-            Mqtt5ClientBuilder &withClientDisconnectionCallback(OnDisconnectionHandler callback) noexcept;
+            Mqtt5ClientBuilder &WithClientDisconnectionCallback(OnDisconnectionHandler callback) noexcept;
 
             /**
              * Setup callback handler trigged when client reaches the "Stopped" state
@@ -466,7 +466,7 @@ namespace Aws
              *
              * @return this option object
              */
-            Mqtt5ClientBuilder &withClientStoppedCallback(OnStoppedHandler callback) noexcept;
+            Mqtt5ClientBuilder &WithClientStoppedCallback(OnStoppedHandler callback) noexcept;
 
             /**
              * Setup callback handler trigged when client begins an attempt to connect to the remote endpoint.
@@ -475,7 +475,7 @@ namespace Aws
              *
              * @return this option object
              */
-            Mqtt5ClientBuilder &withClientAttemptingConnectCallback(OnAttemptingConnectHandler callback) noexcept;
+            Mqtt5ClientBuilder &WithClientAttemptingConnectCallback(OnAttemptingConnectHandler callback) noexcept;
 
             /**
              * Setup callback handler trigged when an MQTT PUBLISH packet is received by the client
@@ -484,7 +484,7 @@ namespace Aws
              *
              * @return this option object
              */
-            Mqtt5ClientBuilder &withPublishReceivedCallback(OnPublishReceivedHandler callback) noexcept;
+            Mqtt5ClientBuilder &WithPublishReceivedCallback(OnPublishReceivedHandler callback) noexcept;
 
           private:
             // Common setup shared by all valid constructors
