@@ -7,6 +7,7 @@
 #include <aws/crt/Exports.h>
 #include <aws/crt/auth/Sigv4Signing.h>
 #include <aws/crt/mqtt/MqttClient.h>
+#include <aws/iot/MqttCommon.h>
 
 #if !BYO_CRYPTO
 
@@ -99,88 +100,6 @@ namespace Aws
             friend class MqttClientConnectionConfigBuilder;
         };
 
-        using CreateSigningConfig = std::function<std::shared_ptr<Crt::Auth::ISigningConfig>(void)>;
-
-        /**
-         * Class encapsulating configuration for establishing an Aws IoT mqtt connection via websockets
-         */
-        struct AWS_CRT_CPP_API WebsocketConfig
-        {
-            /**
-             * Create a websocket configuration for use with the default credentials provider chain. Signing region
-             * will be used for Sigv4 signature calculations.
-             *
-             * @param signingRegion Aws region that is being connected to.  Required in order to properly sign the
-             * handshake upgrade request
-             * @param bootstrap client bootstrap to establish any connections needed by the default credentials
-             * provider chain which will get built for the user
-             * @param allocator memory allocator to use
-             */
-            WebsocketConfig(
-                const Crt::String &signingRegion,
-                Crt::Io::ClientBootstrap *bootstrap,
-                Crt::Allocator *allocator = Crt::ApiAllocator()) noexcept;
-
-            /**
-             * Create a websocket configuration for use with the default credentials provider chain and default
-             * ClientBootstrap. Signing region will be used for Sigv4 signature calculations.
-             *
-             * For more information on the default ClientBootstrap see
-             * Aws::Crt::ApiHandle::GetOrCreateDefaultClientBootstrap
-             *
-             * @param signingRegion Aws region that is being connected to.  Required in order to properly sign the
-             * handshake upgrade request
-             * @param allocator memory allocator to use
-             */
-            WebsocketConfig(const Crt::String &signingRegion, Crt::Allocator *allocator = Crt::ApiAllocator()) noexcept;
-
-            /**
-             * Create a websocket configuration for use with a custom credentials provider. Signing region will be used
-             * for Sigv4 signature calculations.
-             *
-             * @param signingRegion Aws region that is being connected to.  Required in order to properly sign the
-             * handshake upgrade request
-             * @param credentialsProvider credentials provider to source AWS credentials from
-             * @param allocator memory allocator to use
-             */
-            WebsocketConfig(
-                const Crt::String &signingRegion,
-                const std::shared_ptr<Crt::Auth::ICredentialsProvider> &credentialsProvider,
-                Crt::Allocator *allocator = Crt::ApiAllocator()) noexcept;
-
-            /**
-             * Create a websocket configuration for use with a custom credentials provider, and a custom signer.
-             *
-             * You'll need to provide a function for use with creating a signing Config and pass it to
-             * createSigningConfig.
-             *
-             * This is useful for cases use with:
-             * https://docs.aws.amazon.com/iot/latest/developerguide/custom-auth.html
-             *
-             * @param credentialsProvider credentials provider
-             * @param signer HTTP request signer
-             * @param createSigningConfig function that creates a signing config
-             */
-            WebsocketConfig(
-                const std::shared_ptr<Crt::Auth::ICredentialsProvider> &credentialsProvider,
-                const std::shared_ptr<Crt::Auth::IHttpRequestSigner> &signer,
-                CreateSigningConfig createSigningConfig) noexcept;
-
-            std::shared_ptr<Crt::Auth::ICredentialsProvider> CredentialsProvider;
-            std::shared_ptr<Crt::Auth::IHttpRequestSigner> Signer;
-            CreateSigningConfig CreateSigningConfigCb;
-
-            /**
-             * @deprecated Specify ProxyOptions to use a proxy with your websocket connection.
-             *
-             * If MqttClientConnectionConfigBuilder::m_proxyOptions is valid, then that will be used over
-             * this value.
-             */
-            Crt::Optional<Crt::Http::HttpClientConnectionProxyOptions> ProxyOptions;
-            Crt::String SigningRegion;
-            Crt::String ServiceName;
-        };
-
         /**
          * Represents configuration parameters for building a MqttClientConnectionConfig object. You can use a single
          * instance of this class PER MqttClientConnectionConfig you want to generate. If you want to generate a config
